==> netbeans_8.0.2+dfsg1.orig.tar.xz: netbeans-8.0.2/cnd.repository/test/unit/src/org/netbeans/modules/cnd/repository/impl/IncrementalParseRepositoryValidationTest.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
 *
 * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
 * Other names may be trademarks of their respective owners.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * Contributor(s):
 *
 * The Original Software is NetBeans. The Initial Developer of the Original
 * Software is Sun Microsystems, Inc. Portions Copyright 1997-2007 Sun
 * Microsystems, Inc. All Rights Reserved.
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 */

package org.netbeans.modules.cnd.repository.impl;

import junit.framework.Test;
import junit.framework.TestSuite;
import org.netbeans.modules.cnd.test.CndBaseTestSuite;

/**
 *
* @author Sergey Grinev
 */
public class IncrementalParseRepositoryValidationTest extends CndBaseTestSuite {

    static {
        System.setProperty("cnd.modelimpl.parser.threads", "8");
        if (Boolean.getBoolean("cnd.modelimpl.trace203833")) {
            System.setProperty("cnd.modelimpl.trace.validation", "true"); // NOI18N
            System.setProperty("cnd.modelimpl.installer.trace", "true"); // NOI18N
            System.setProperty("cnd.skip.err.check", "true");
        }
//        System.setProperty("cnd.modelimpl.trace203833", "true"); // NOI18N
//        System.setProperty("cnd.pp.condition.comparision.trace", "true");
//        System.setProperty("cnd.modelimpl.trace.file", "gmodule-dl.c");
    }

    public IncrementalParseRepositoryValidationTest() {
        super("Incremental Extra Parse Repository"); // NOI18N
        
        addTestSuite(RepositoryValidationGoldens.class);
        addTestSuite(RepositoryValidationInterruptedParse.class);
        addTestSuite(IncrementalParseRepositoryValidationFinal.class);
    }

    public static Test suite() {
        TestSuite suite = new IncrementalParseRepositoryValidationTest();
        return suite;
    }
    
}

==> netbeans_8.1+dfsg3.orig.tar.xz: netbeans-8.1/cnd.repository/test/unit/src/org/netbeans/modules/cnd/repository/impl/IncrementalParseRepositoryValidationTest.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
 *
 * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
 * Other names may be trademarks of their respective owners.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * Contributor(s):
 *
 * The Original Software is NetBeans. The Initial Developer of the Original
 * Software is Sun Microsystems, Inc. Portions Copyright 1997-2007 Sun
 * Microsystems, Inc. All Rights Reserved.
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 */

package org.netbeans.modules.cnd.repository.impl;

import junit.framework.Test;
import junit.framework.TestSuite;
import org.netbeans.modules.cnd.test.CndBaseTestSuite;

/**
 *
* @author Sergey Grinev
 */
public class IncrementalParseRepositoryValidationTest extends CndBaseTestSuite {

    static {
        System.setProperty("cnd.modelimpl.parser.threads", "8");
        if (Boolean.getBoolean("cnd.modelimpl.trace203833")) {
            System.setProperty("cnd.modelimpl.trace.validation", "true"); // NOI18N
            System.setProperty("cnd.modelimpl.installer.trace", "true"); // NOI18N
            System.setProperty("cnd.skip.err.check", "true");
        }
        System.setProperty("cnd.dump.skip.dummy.forward.classifier", Boolean.TRUE.toString()); //NOI18N
//        System.setProperty("cnd.modelimpl.trace203833", "true"); // NOI18N
//        System.setProperty("cnd.pp.condition.comparision.trace", "true");
//        System.setProperty("cnd.modelimpl.trace.file", "gmodule-dl.c");
    }

    public IncrementalParseRepositoryValidationTest() {
        super("Incremental Extra Parse Repository"); // NOI18N
        
        addTestSuite(IncrementalParseRepositoryComposite.class);
    }

    public static Test suite() {
        TestSuite suite = new IncrementalParseRepositoryValidationTest();
        return suite;
    }
    
}
